@@ -38,6 +38,12 @@ public:
     QVariant data(const QModelIndex &index, int role) const override;
     QHash<int, QByteArray> roleNames() const override;
 
+    /** Human-readable title for displaying for the given certificate. */
+    [[nodiscard]] static QString displayName(const QVariant &cert);
+
+    /** Raw data representation of @p cert, independent of its type. */
+    [[nodiscard]] static QByteArray certificateRawData(const QVariant &cert);
+
 Q_SIGNALS:
     void newCertificateLoaded(int index);
 
@@ -49,7 +55,6 @@ private:
     static bool certLessThan(const CertData &lhs, const CertData &rhs);
 
     void loadCertificates();
-    QByteArray certificateRawData(const CertData &certData) const;
 
     std::vector<CertData> m_certificates;
 };
