@@ -8,12 +8,12 @@
 
 #include "eventdata.h"
 
-#include <kandroidextras/jniobject.h>
-#include <kandroidextras/jnimethod.h>
-#include <kandroidextras/jniproperty.h>
-#include <kandroidextras/jnitypes.h>
-#include <kandroidextras/javatypes.h>
-#include <kandroidextras/androidtypes.h>
+#include "kandroidextras/jniobject.h"
+#include "kandroidextras/jnimethod.h"
+#include "kandroidextras/jniproperty.h"
+#include "kandroidextras/jnitypes.h"
+#include "kandroidextras/javatypes.h"
+#include "kandroidextras/androidtypes.h"
 
 JNI_TYPE(org, kde, kcalendarcore, Calendar)
 
