@@ -27,11 +27,6 @@ int main(int argc, char **argv)
     QCoreApplication::setApplicationName(QStringLiteral("vehiclelayoutviewer"));
     QCoreApplication::setOrganizationName(QStringLiteral("KDE"));
     QCoreApplication::setOrganizationDomain(QStringLiteral("kde.org"));
-
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
-    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
-#endif
     QGuiApplication app(argc, argv);
 
     QCommandLineParser parser;
